#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IDIVFLOOR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IDIVFLOOR_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/idivfloor.hpp>

#endif
